#!/etc/opt/openit/perl -w
#
# Add duration to acc_types dt 94 
#

use strict;

&verify_root();
&update_acc_types();


sub update_acc_types {
    my ($filter) = @_;

    my $file = "/var/opt/openit/etc/acc_types";
    my $old  = "$file.old";
    my $new  = "$file.new";

    # Check that file exists
    if (! -r $file) {
        print "Skipping non-existing filter '$filter'\n";
        return;
    }

    # Read config file into array
    open(IN,  "<$file") || die "Error: Unable to read old file '$file'!\n";
    my @config = <IN>;
    close(IN);


    # Do updates ( mark changes )

    #
    # Find the position after Max used in Olap user concurrency
    #
    my $ind = 0;
    while( $ind < scalar(@config) && $config[$ind] !~ /Olap.user.concurrency/i) {$ind++};
    $ind++;
    while( $ind < scalar(@config) && $config[$ind] !~ /Max.used/i) {$ind++};
    $ind++;

    # Check for duration
    if ( $config[$ind] =~ /Duration/ ) { # No changes needed
        unlink $new; #
        print "Skipping update of 'acc_types' (already done)!\n";
        return;
    }

    # Add Duration
    splice( @config, $ind, 0,
	    "   (Duration, Duration^for^user^in^hours,Hour,SUM),\n");


    #
    # Find the position after Min used in Usergroup license use v3
    #
    while( $ind < scalar(@config) && $config[$ind] !~ /Usergroup.license.use.v3/i) {$ind++};
    $ind++;
    while( $ind < scalar(@config) && $config[$ind] !~ /Min.used/i) {$ind++};
    $ind++;

    # Add Duration
    splice( @config, $ind, 0,
	    "   (Duration, Duration^for^group^in^hours,Hour,SUM),\n");


    # Write output
    open(OUT, ">$new")  || die "Error: Can't write new file '$new'!\n";
    foreach my $line (@config) {
        print OUT $line;
    }
    close(OUT);

    # Commit change
    if( ! rename($file, $old)) {
        die "Error: Unable to previous config to '$old'!\n";
    }

    if( ! rename($new, $file)) {
        die "Error: Unable to rename new config to '$file'!\n";
    }

    print "Updated acc_types\n";
}


sub verify_root {
    # Only root can patch
    if ( $< ne 0 ) {
        die "Error: Patching must be done as 'root'!\n";
    }
}
